summaryrefslogtreecommitdiffstats
path: root/kmail/kmmessage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmessage.h')
-rw-r--r--kmail/kmmessage.h60
1 files changed, 30 insertions, 30 deletions
diff --git a/kmail/kmmessage.h b/kmail/kmmessage.h
index a063ca1a..32e79e2a 100644
--- a/kmail/kmmessage.h
+++ b/kmail/kmmessage.h
@@ -71,7 +71,7 @@ class KMMessage: public KMMsgBase, public KMail::ISubject
public:
// promote some of KMMsgBase's methods to public:
- using KMMsgBase::parent;
+ using KMMsgBase::tqparent;
using KMMsgBase::setParent;
using KMMsgBase::enableUndo; // KMFolder
using KMMsgBase::setEnableUndo; // dto.
@@ -85,7 +85,7 @@ public:
using KMMsgBase::setSignatureStateChar; // dto.
/** Straight forward initialization. */
- KMMessage(KMFolder* parent=0);
+ KMMessage(KMFolder* tqparent=0);
/** Constructor from a DwMessage. KMMessage takes possession of the
DwMessage, so don't dare to delete it.
@@ -131,7 +131,7 @@ public:
*/
void setUnencryptedMsg( KMMessage* unencrypted );
- /** Returns TRUE if the message tqcontains an unencrypted copy of itself. */
+ /** Returns TRUE if the message contains an unencrypted copy of itself. */
bool hasUnencryptedMsg() const { return 0 != mUnencryptedMsg; }
/** Returns an unencrypted copy of this message or 0 if none exists. */
@@ -150,21 +150,21 @@ public:
}
/** Mark the message as deleted */
- void del() { seStatus(KMMsgStatusDeleted); }
+ void del() { setqStatus(KMMsgStatusDeleted); }
/** Undelete the message. Same as touch */
- void undel() { seStatus(KMMsgStatusOld); }
+ void undel() { setqStatus(KMMsgStatusOld); }
/** Touch the message - mark it as read */
- void touch() { seStatus(KMMsgStatusOld); }
+ void touch() { setqStatus(KMMsgStatusOld); }
/** Create a new message that is a reply to this message, filling all
required header fields with the proper values. The returned message
is not stored in any folder. Marks this message as replied. */
KMMessage* createReply( KMail::ReplyStrategy replyStrategy = KMail::ReplySmart,
- TQString selection=TQString::null, bool noQuote = false,
+ TQString selection=TQString(), bool noQuote = false,
bool allowDecryption = true,
- const TQString &tmpl = TQString::null );
+ const TQString &tmpl = TQString() );
/** Create a new message that is a redirect to this message, filling all
required header fields with the proper values. The returned message
@@ -181,7 +181,7 @@ public:
/** Create a new message that is a forward of this message, filling all
required header fields with the proper values. The returned message
is not stored in any folder. Marks this message as forwarded. */
- KMMessage* createForward( const TQString &tmpl = TQString::null );
+ KMMessage* createForward( const TQString &tmpl = TQString() );
/** Create a new message that is a delivery receipt of this message,
filling required header fileds with the proper values. The
@@ -210,9 +210,9 @@ public:
void sanitizeHeaders( const TQStringList& whiteList = TQStringList() );
/** Parse the string and create this message from it. */
- void fromDwString(const DwString& str, bool seStatus=false);
- void fromString(const TQCString& str, bool seStatus=false);
- void fromByteArray(const TQByteArray & ba, bool seStatus=false);
+ void fromDwString(const DwString& str, bool setqStatus=false);
+ void fromString(const TQCString& str, bool setqStatus=false);
+ void fromByteArray(const TQByteArray & ba, bool setqStatus=false);
/** Return the entire message contents in the DwString. This function
is *fast* even for large message since it does *not* involve a
@@ -243,7 +243,7 @@ public:
TQCString headerAsSendableString() const;
/**
- * Remove all private header fields: *Status: and X-KMail-*
+ * Remove all private header fields: *tqStatus: and X-KMail-*
**/
void removePrivateHeaderFields();
@@ -274,7 +274,7 @@ public:
/** @return the UOID of the identity for this message.
Searches the "x-kmail-identity" header and if that fails,
searches with KPIM::IdentityManager::identityForAddress()
- and if that fails queries the KMMsgBase::parent() folder for a default.
+ and if that fails queries the KMMsgBase::tqparent() folder for a default.
**/
uint identityUoid() const;
@@ -663,11 +663,11 @@ public:
/**
* Delete a body part with the specified part index.
* A dummy body part with the text "the attachment foo was deleted" will tqreplace the old part.
*/
bool deleteBodyPart( int partIndex );
- /** Set "Status" and "X-Status" fields of the message from the
+ /** Set "tqStatus" and "X-tqStatus" fields of the message from the
* internal message status. */
void seStatusFields();
@@ -679,7 +679,7 @@ public:
/** Convert '<' into "&lt;" resp. '>' into "&gt;" in order to
* prevent their interpretation by KHTML.
* Does *not* use the Qt tqreplace function but runs a very fast C code
* the same way as lf2crlf() does.
*/
static TQCString html2source( const TQCString & src );
@@ -717,7 +717,7 @@ public:
* only the name part and not the given emailAddr.
*/
static TQString emailAddrAsAnchor(const TQString& emailAddr,
- bool stripped=true, const TQString& cssStyle = TQString::null, bool link = true);
+ bool stripped=true, const TQString& cssStyle = TQString(), bool link = true);
/** Strips an address from an address list. This is for example used
when replying to all.
@@ -760,7 +760,7 @@ public:
static const TQStringList &preferredCharsets();
/** Replaces every occurrence of "${foo}" in @p s with headerField("foo") */
- TQString tqreplaceHeadersInString( const TQString & s ) const;
+ TQString replaceHeadersInString( const TQString & s ) const;
/** Get the message charset.*/
TQCString charset() const;
@@ -822,11 +822,11 @@ public:
ulong UID() const;
void setUID(ulong uid);
- /** Status of the message. */
- KMMsgStatus status() const { return mStatus; }
+ /** tqStatus of the message. */
+ KMMsgtqStatus status() const { return mtqStatus; }
/** Set status and mark dirty. */
- void seStatus(const KMMsgStatus status, int idx = -1);
- void seStatus(const char* s1, const char* s2=0) { KMMsgBase::seStatus(s1, s2); }
+ void setqStatus(const KMMsgtqStatus status, int idx = -1);
+ void setqStatus(const char* s1, const char* s2=0) { KMMsgBase::setqStatus(s1, s2); }
/** Set encryption status of the message. */
void setEncryptionState(const KMMsgEncryptionState, int idx = -1);
@@ -844,11 +844,11 @@ public:
KMMsgMDNSentState mdnSentState() const { return mMDNSentState; }
- /** Links this message to @p aMsg, setting link type to @p aStatus. */
- void link(const KMMessage *aMsg, KMMsgStatus aStatus);
+ /** Links this message to @p aMsg, setting link type to @p atqStatus. */
+ void link(const KMMessage *aMsg, KMMsgtqStatus atqStatus);
/** Returns the information for the Nth link into @p retMsg
- * and @p reStatus. */
- void getLink(int n, ulong *retMsgSerNum, KMMsgStatus *reStatus) const;
+ * and @p retqStatus. */
+ void getLink(int n, ulong *retMsgSerNum, KMMsgtqStatus *retqStatus) const;
/** Convert wildcards into normal string */
TQString formatString(const TQString&) const;
@@ -886,7 +886,7 @@ public:
/** Returns message body with quoting header and indented by the
given indentation string. This is suitable for including the message
in another message of for replies, forwards. The header string is
- a template where the following fields are tqreplaced with the
+ a template where the following fields are replaced with the
corresponding values:
<pre>
%D: date of this message
@@ -900,7 +900,7 @@ public:
get converted to plain text when allowDecryption is true. */
TQString asQuotedString( const TQString & headerStr,
const TQString & indentStr,
- const TQString & selection=TQString::null,
+ const TQString & selection=TQString(),
bool aStripSignature=true,
bool allowDecryption=true) const;
@@ -969,7 +969,7 @@ private:
KMMessage* mUnencryptedMsg;
DwBodyPart* mLastUpdated;
int mCursorPos;
- KMMsgInfo* mMsgInfo; // used to remember the KMMsgInfo object this KMMessage tqreplaced in the KMMsgList
+ KMMsgInfo* mMsgInfo; // used to remember the KMMsgInfo object this KMMessage replaced in the KMMsgList
static TQValueList<KMMessage*> sPendingDeletes;
};
@@ -663,11 +663,11 @@ public:
/**
* Delete a body part with the specified part index.
- * A dummy body part with the text "the attachment foo was deleted" will tqreplace the old part.
+ * A dummy body part with the text "the attachment foo was deleted" will replace the old part.
*/
bool deleteBodyPart( int partIndex );
@@ -679,7 +679,7 @@ public:
/** Convert '<' into "&lt;" resp. '>' into "&gt;" in order to
* prevent their interpretation by KHTML.
- * Does *not* use the Qt tqreplace function but runs a very fast C code
+ * Does *not* use the TQt replace function but runs a very fast C code
* the same way as lf2crlf() does.
*/